Crate datafusion_data_access
datafusion_
data_
access
10.0.0
All Items
Crate Items
Modules
Structs
Enums
Type Aliases
Crate
datafusion_
data_
access
Modules

object_
store
Object Store abstracts access to an underlying file/object storage.
Structs

File
Meta
Description of a file as returned by the listing command of a given object store. The resulting path is relative to the object store that generated it.
Sized
File
The path and size of the file.
Enums

List
Entry
Represents a specific file or a prefix (folder) that may require further resolution
Type Aliases

Result
Result type for operations that could result in an io error